/*
 * Copyright (C) 2005-2013 Schlichtherle IT Services.
 * All rights reserved. Use is subject to license terms.
 */
package de.schlichtherle.xml;

import java.security.*;
import javax.annotation.*;
import net.java.truelicense.core.LicenseXmlCodec;
import net.java.truelicense.core.auth.*;
import net.java.truelicense.core.codec.Codec;
import net.java.truelicense.obfuscate.Obfuscate;

/**
 * Provides interoperability with version 1 (V1) format license keys as used
 * by TrueLicense 1.X applications.
 * This type of repository is used in V1 format license keys.
 *
 * @author Christian Schlichtherle
 */
public final class GenericCertificate implements Repository {

    @Obfuscate private static final String SIGNATURE_ENCODING = "US-ASCII/Base64";

    private final BasicRepository repository = new BasicRepository() {
        final Codec codec = new LicenseXmlCodec();

        @Override public Codec codec() { return codec; }
    };

    private @CheckForNull String signatureEncoding;

    protected BasicRepository repository() { return repository; }

    public @Nullable String getEncoded()   {
        return repository().getArtifact();
    }

    public void setEncoded(@CheckForNull String encoded) {
        repository().setArtifact(encoded);
    }

    public @Nullable String getSignatureAlgorithm()  {
        return repository().getSignatureAlgorithm();
    }

    public void setSignatureAlgorithm(@CheckForNull String algorithm) {
        repository().setSignatureAlgorithm(algorithm);
    }

    public @Nullable String getSignatureEncoding() { return signatureEncoding; }

    public void setSignatureEncoding(final @CheckForNull String signatureEncoding) {
        this.signatureEncoding = signatureEncoding;
    }

    public @Nullable String getSignature() {
        return repository().getSignature();
    }

    public void setSignature(@CheckForNull String signature) {
        repository().setSignature(signature);
    }

    @Override
    public <A> Artifactory<A> sign(
            final Signature engine,
            final PrivateKey key,
            final A artifact)
    throws Exception {
        final Artifactory<A> a = repository().sign(engine, key, artifact);
        setSignatureEncoding(SIGNATURE_ENCODING);
        return a;
    }

    @Override
    public Artifactory<?> verify(
            final Signature engine,
            final PublicKey key)
    throws Exception {
        if (!getSignatureEncoding().equalsIgnoreCase(SIGNATURE_ENCODING))
            throw new IllegalStateException();
        return repository().verify(engine, key);
    }

    @Override
    public boolean equals(final Object obj) {
        if (this == obj) return true;
        if (!(obj instanceof GenericCertificate)) return false;
        final GenericCertificate that = (GenericCertificate) obj;
        return this.repository().equals(that.repository());
    }

    @Override
    public int hashCode() {
        return repository().hashCode();
    }
}
