/*
 * Copyright (C) 2005-2013 Schlichtherle IT Services.
 * All rights reserved. Use is subject to license terms.
 */
package net.java.truelicense.core;

import javax.xml.bind.*;
import javax.xml.bind.annotation.XmlRootElement;
import net.java.truelicense.core.auth.*;
import net.java.truelicense.core.codec.*;

/**
 * A repository which uses a {@link V2XmlCodec} to encode/decode
 * {@link License}s for signing/verifying.
 * This type of repository is used in V2/XML format license keys.
 *
 * @author Christian Schlichtherle
 */
@XmlRootElement(name = "repository")
public class V2XmlLicenseRepository extends BasicRepository {

    private final Codec codec;

    public V2XmlLicenseRepository() {
        try {
            codec = new V2XmlCodec(JAXBContext.newInstance(License.class));
        } catch (final JAXBException ex) {
            throw new AssertionError(ex);
        }
    }

    @Override public Codec codec() { return codec; }
}
