/*
 * Copyright (C) 2005-2013 Schlichtherle IT Services.
 * All rights reserved. Use is subject to license terms.
 */
package net.java.truelicense.core.auth;

import javax.annotation.CheckForNull;

/**
 * Defines authentication services.
 *
 * @author Christian Schlichtherle
 */
public interface Authentication extends AuthenticationParametersProvider {

    /**
     * Encodes and signs the given {@code artifact} in the given
     * {@code repository} and returns an artifactory for it.
     * After calling this method, the repository typically gets serialized for
     * future deserialization and verification.
     *
     * @param  repository the repository to use.
     * @param  artifact the nullable artifact to sign.
     */
    <A> Artifactory<A> sign(Repository repository, @CheckForNull A artifact)
    throws Exception;

    /**
     * Verifies the signature of the encoded artifact in the given
     * {@code repository} and returns an artifactory for it.
     * Calling this method generally requires prior initialization of the
     * repository.
     * Though initialization is a side effect of calling {@link #sign}, this is
     * typically done by deserializing the repository.
     *
     * @param  repository the repository to use.
     * @throws RepositoryIntegrityException if the integrity of this repository
     *         with its encoded artifact has been compromised.
     */
    Artifactory<?> verify(Repository repository) throws Exception;
}
